@@ -5,13 +5,16 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Scalar;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.050002';
+our $VERSION   = '0.050003';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
 
 use Sub::HandlesVia::Handler qw( handler );
-our @METHODS = qw( scalar_reference make_getter make_setter );
+our @METHODS = qw(
+	scalar_reference make_getter make_setter get set
+	stringify
+);
 
 sub scalar_reference {
 	handler
@@ -67,4 +70,32 @@ sub make_setter {
 		allow_getter_shortcuts => 0,
 }
 
+sub get {
+	handler
+		name      => 'Scalar:get',
+		args      => 0,
+		template  => '$GET',
+		documentation => "Gets the current value of the scalar.",
+		allow_getter_shortcuts => 0,
+}
+
+sub set {
+	handler
+		name      => 'Scalar:set',
+		args      => 1,
+		template  => '« $ARG »',
+		lvalue_template => '$GET = $ARG',
+		usage     => '$value',
+		documentation => "Sets the scalar to a new value.",
+}
+
+sub stringify {
+	handler
+		name      => 'Scalar:stringify',
+		args      => 0,
+		template  => 'do { my $shv_tmp = $GET; sprintf q(%s), $shv_tmp; }',
+		documentation => "Gets the current value of the scalar, but as a string.",
+		allow_getter_shortcuts => 0,
+}
+
 1;
